#
# nonsoft-round-heap.R, 29 May 22

library("colorspace")
library("plyr")

par(bty="l")
par(las=1)
par(pch="+")

pal_col=rainbow(2)


scf=read.csv("scf369_rnd_ans.csv.xz", as.is=true)
mort_act=read.csv("mortgages.csv", as.is=TRUE)

scf13=subset(scf, year == 2013)

mort_cnt=count(scf13$x804)

# # Total mortgages and divide to get normalising scale factor
# scf_sub=subset(scf13, (x804 > 1) & (x804 < 7e5))
# sum(scf_sub$x804)/sum(mort_act$density)

plot(mort_cnt$x/1e3, mort_cnt$freq, col=pal_col[1],
	xaxs="i", yaxs="i",
	xlim=c(0, 700), ylim=c(0, 350),
	xlab="Mortgage balance in $1000", ylab="Households")

# Scale actual
lines(mort_act$amount, mort_act$density*2.58e4, col=pal_col[2])

legend("topright", legend=c("Survey estimates", "Actual for New York"),
		bty="n", fil=pal_col, cex=1.3)


# Objective and Subjective Quality of Life in Poland survey data
osql=read.csv("OSQL-Poland.csv", as.is=TRUE)

osql$ap83_2=as.numeric(osql$ap83_2)
osql$ap65=as.numeric(osql$ap65)
cig_cnt=count(osql$ap83_2)
friend_cnt=count(osql$ap65)

plot(cig_cnt, col=pal_col[1], type="b",
	xaxs="i", yaxs="i",
	xlim=c(0, 60), ylim=c(0, 1060),
	xlab="Items", ylab="People")
lines(friend_cnt, col=pal_col[2], type="b")

legend("topright", legend=c("Cigarettes per day", "Friends"),
		bty="n", fil=pal_col, cex=1.3)


# Code to extract data from original sources

# library("foreign")
# library("readstata13") # foreign does not handle later format versions
# 
# 
# # Download the stata files here:
# # https://www.federalreserve.gov/econres/scf-previous-surveys.htm
# 
# scf13=read.dta13("../scf2019ascii/p13i6.dta")
# scf16=read.dta13("../scf2019ascii/p16i6.dta")
# scf19=read.dta13("../scf2019ascii/p19i6.dta")
# 
# # Extract of columns that look applicable
# # https://www.federalreserve.gov/econres/files/codebk2013.txt
# # 
# # X708            How much rent do you (or your family living here) pay for this
# #                 (farm/ranch/house/apartment)?
# #                 
# #                 IF RENT IS SUBSIDIZED, PROBE FOR DETAILS AND MAKE NOTE.
# #                 DO NOT INCLUDE ANY SHARE OF THE RENT PAID BY THE NPEU
# #                 INCLUDE ANY FEES FOR PARKING WITH RENT.
# # 
# #                 If household rents and there is an NPEU:
# #                 NPEU IN THIS HOUSEHOLD:
# #                 DO NOT INCLUDE ANY SHARE OF THE RENT PAID BY THE NPEU
# #                 
# #                 $ AMOUNT:
# #                     -1.     None
# #                      0.     Inap. (R lives in MH: X501=2; R lives on farm
# #                             operated as a business, but does not
# #                             rent: X501=(4, 5) and X503=1 and
# #                             X508^=3; some living arrangement
# #                             other than rents: X701^=2)
# #                 *********************************************************
# #                     ORIGINALLY ALLOWED VALUES: [0,...,99999]
# #                 
# #                     IF < 0 OUT OF RANGE: ILLEGAL VALUE ERROR MESSAGE
# #                 *********************************************************
# # 
# # 
# # X709            INTERVIEWER: CODE WITHOUT ASKING IF ALREADY MENTIONED.
# #                 (And that amount is per...?)
# #                 
# #                 FREQUENCY:
# #                      2.    *Week
# #                      3.    *Every two weeks
# #                      4.    *Month
# #                      5.    *Quarter
# #                      6.    *Year
# #                     11.    *Twice per year
# #                     12.     Every two months
# #                     31.    *Twice a month
# #                     -1.     None
# #                     -7.    *Other
# #                      0.     Inap. (R lives in MH: X501=2; R lives on farm
# #                             operated as a business, but does not
# #                             rent: X501=(4, 5) and X503=1 and
# #                             X508^=3; some living arrangement
# #                             other than rents: X701^=2)
# # 
# # X411(#1)        How many?
# # X419(#2)        Please do not count duplicate cards for the same account or
# # X425(#3)        any business or company accounts.
# #                 
# #                 INCLUDE ALL THE FAMILY'S CARDS, NOT JUST THE CARDS USED
# #                 MOST OFTEN.
# #                 DO NOT INCLUDE GIFT CARDS.
# #                 
# #                 NUMBER OF ACCOUNTS:
# #                      0.     Inap. (no credit cards: X410=5; no cards of type)
# #                 *********************************************************
# #                     ORIGINALLY ALLOWED VALUES: [1,...,99]
# #                 
# #                     IF < 1 OUT OF RANGE: ILLEGAL VALUE ERROR MESSAGE
# #                 *********************************************************
# #                     FOR THE PUBLIC DATA SET, THE NUMBER OF #1/2 CARDS
# #                     IS TOP-CODED AT 10 AND THE NUMBER OF #3/4 CARDS
# #                     IS TOP-CODED AT 5
# #                 *********************************************************
# # 
# # 
# # X412(#1)        On your last bill(s), how much were the new charges
# # X420(#2)        made to (this account/these accounts)?
# # X426(#3)        
# #                 IF R DID NOT RECEIVE A BILL LAST MONTH, CODE ZERO.
# #                 
# #                 $ AMOUNT:
# #                     -1.     None
# #                      0.     Inap. (no credit cards: X410=5; no cards of type)
# #                 *********************************************************
# #                     ORIGINALLY ALLOWED VALUES: [0,...,9999999]
# #                 
# #                     IF < 0 OUT OF RANGE: ILLEGAL VALUE ERROR MESSAGE
# #                 *********************************************************
# # 
# # 
# # X413(#1)        After the last payment(s) (was/were) made, what was the total
# # X421(#2)        balance still owed on (this account/all these accounts)?
# #                 
# #                 WE WANT THE TOTAL AMOUNT OWED, NOT THE MINIMUM PAYMENT.
# #                 CODE ZERO IF ALL ACCOUNTS WERE PAID IN FULL.
# #                 
# #                 $ AMOUNT:
# #                     -1.     None
# #                      0.     Inap. (no credit cards: X410=5; no cards of type)
# #                 *********************************************************
# #                     ORIGINALLY ALLOWED VALUES: [0,...,9999999]
# #                 
# #                     IF < 0 OUT OF RANGE: ILLEGAL VALUE ERROR MESSAGE
# #                 *********************************************************
# # 
# # X804(#1)        What was the amount of the land contract when you took it out?
# #                 
# #                 Including both the amount refinanced and the additional
# #                 borrowing, how much did you borrow?
# #                 
# #                 How much did you refinance or rollover?
# #                 
# #                 How much did you borrow or refinance?
# #                 
# #                 IF R HAS REVERSE ANNUITY MORTGAGE, THE AMOUNT BORROWED IS
# #                 THE TOTAL AMOUNT RECEIVED TO DATE.
# #                 
# #                 $ AMOUNT:
# #                      0.     Inap. (does not own any part of HU: X508^=(1, 2)
# #                             and X601^=(1, 2, 3) and X701^=(1, 3, 4,
# #                             5, 6, 8) and X7133^=1; no first mortgage:
# #                             X723^=(1, 2)/no second mortgage:
# #                             X830^=1/no third mortgage: X931^=1 or
# #                             (X723=5 and X830^=1))
# #                 *********************************************************
# #                     ORIGINALLY ALLOWED VALUES: [1,...,99999999]
# #                 
# #                     IF < 1 OUT OF RANGE: ILLEGAL VALUE ERROR MESSAGE
# #                 *********************************************************
# #                 EDIT CHECK:
# #                 If the additional amount borrowed is greater than or 
# #                 equal to the amount borrowed:
# #                 
# #                   IF X7138 > X804
# #                 
# #                 CAPI text displayed:
# #                   ATTENTION:
# #                   R REPORTED EXTRACTING ADDITIONAL EQUITY, BUT AMOUNT
# #                   EXTRACTED OF X7138 SAME OR LARGER THAN AMOUNT BORROWED
# #                   OF X804.
# #                 
# #                     COMMENT LATER
# #                     COMMENT NOW
# #                 *********************************************************
# # 
# # X805(#1)        What is the amount still owed on the land contract?
# #                 
# #                 $ AMOUNT:
# #                      0.     Inap. (does not own any part of HU: X508^=(1, 2)
# #                             and X601^=(1, 2, 3) and X701^=(1, 3, 4,
# #                             5, 6) and X7133^=1; no first mortgage:
# #                             X723^=1 or 2/no second mortgage:
# #                             X830^=1/no third mortgage: X931^=1
# #                             or (X723=5 and X830^=1))
# #                 *********************************************************
# #                     ORIGINALLY ALLOWED VALUES: [1,...,99999999]
# #                 
# #                     IF < 1 OUT OF RANGE: ILLEGAL VALUE ERROR MESSAGE
# #                 *********************************************************
# #                 EDIT CHECK:
# #                 If the amount owed is greater than the amount borrowed:
# #                   IF X805 > X804:
# # 
# #                 CAPI test displayed:
# # 
# #                   ATTENTION:
# #                   AMOUNT OWED IS GREATER THAN THE AMOUNT BORROWED.
# #                   PLEASE CONFIRM THAT AMOUNT OWED X805 AND AMOUNT
# #                   BORROWED X804 ARE CORRECT
# # 
# #                     COMMENT LATER
# #                     COMMENT NOW
# #                 *********************************************************
# # 
# # 
# # X3506(#1)       How much is in this account?
# # X3510(#2)
# # X3514(#3)       PROBE: What was the average over the
# # X3518(#4)       last month?
# #                 
# #                 $ AMOUNT:
# #                     -1.     Nothing
# #                      0.     Inap. (R has no checking account: X3501^=1/
# #                             fewer than 2 accounts: X3504<2/fewer
# #                             than 3 accounts: X3504<3/ fewer than
# #                             4 accounts: X3504<4/fewer than 5
# #                             accounts: X3504<5/fewer than 6
# #                             accounts: X3504<6)
# #                 *********************************************************
# #                     ORIGINALLY ALLOWED VALUES: [0,...,99999999]
# #                 
# #                     IF < 0, OUT OF RANGE: ILLEGAL VALUE ERROR MESSAGE
# #                 *********************************************************
# # 
# # 
# # X3531           For how many years have you done business with this
# #                 institution?
# #                 
# #                 For how many years has someone in your family living here
# #                 done business with this institution?
# # 
# #                 IF INSTITUTION MERGED WITH ANOTHER, WE WANT THE
# #                 LONGEST TIME R HAS DONE BUSINESS WITH ANY PART
# #                 OF THE INSTITUTION
# #                 
# #                 NUMBER OF YEARS:
# #                     -1.     Less than one year
# #                      0.     Inap. (R has no checking accounts: X3501^=1)
# #                 *********************************************************
# #                     ORIGINALLY ALLOWED VALUES: [0,...,99]
# #                 
# #                     IF OUT OF RANGE: ILLEGAL VALUE ERROR MESSAGE
# #                 
# #                     IF > X8021: GREATER THAN CURRENT AGE MESSAGE
# #                 *********************************************************
# #                     FOR THE PUBLIC DATA SET, TOP-CODED 60
# #                 *********************************************************
# # 
# # 
# # X3730(#1)       How much is in this account?
# # X3736(#2)       
# # X3742(#3)       $ AMOUNT:
# # X3748(#4)           -1.     Nothing
# #                      0.     Inap. (no savings accounts: X3727^=1/fewer than 2
# #                             accounts: X3728<2/fewer than 3 account: X3728<3/
# #                             fewer than 4 accounts: X3728<4/fewer than 5
# #                             accounts: X3728<5/fewer than 6 accounts)
# #                 *********************************************************
# #                     ORIGINALLY ALLOWED VALUES: [1,...,999999999]
# #                 
# #                     IF < 1, OUT OF RANGE: ILLEGAL VALUE ERROR MESSAGE
# #                 *********************************************************
# 
# 
# st=scf13
# 
# # Subset of numeric columns having a likely rounded value
# # Columns having a reasonable percentage of actual values
# 
# rnd_data=data.frame(st$x708,
# 			st$x709,
# 			st$x411,
# 			st$x419,
# 			st$x425,
# 			st$x412,
# 			st$x420,
# 			st$x426,
# 			st$x413,
# 			st$x421,
# 			st$x804,
# 			st$x805,
# 			st$x3506,
# 			st$x3510,
# 			st$x3514,
# 			st$x3518,
# 			st$x3730,
# 			st$x3736,
# 			st$x3742,
# 			st$x3748,
# 			year=2013)
# 
# write.csv(rnd_data, file="scf13_rnd_ans.csv", row.names=FALSE)
# 
# 
# #  Social Diagnosis 2000-2013
# # Objective and Subjective Quality of Life in Poland 
# # http://www.diagnoza.com/index-en.html
# # Individual data
# # http://www.diagnoza.com/data/database/2000_2015/SOCIAL_DIAGNOSIS_IND_2000_2015_sav.zip
# # Questionnaire in mostly English
# # http://www.diagnoza.com/data/questionnaires/questionnaires_2015.pdf
# 
# sdi=read.spss("../SOCIAL_DIAGNOSIS_IND_2000_2015.sav")
# 
# # Find out which columns contain the info we are after
# t=attributes(sdi)
# 
# # str(t)
# # head(t$variable.labels) # English description of column contents
# # q=t$variable.labels
# # write.csv(q, file="variable-labels.txt")
# 
# # "YEAR_OF_BIRTH","YEAR OF BIRTH"
# # "ad6","HOW MANY HOURS WORKED IN THE LAST 7 DAYS"
# # "ap65","NUMBER OF FRIENDS"
# # "ap83_2","HOW MANY CIGARETTES PER DAY"
# # "fp55","HOW TALL ARE YOU?"
# # "fp56","WHAT IS YOUR WEIGHT? "
# # "fp65","PERSONAL MONTHLY NET INCOME"
# # "fp66","WHAT MONTHLY NET INCOME DO YOU EXPECT IN TWO YEARS?"
# # "HP111_1","HOW MANY BOOKS PRINTED"
# # "HP131","HOW MUCH TIME DO YOU SPEND USING THE COMPUTER LAST WEEK? (IN HOURS)"
# # "HP133","HOW MANY HOURS HAVE YOU SPENT USING THE INTERNET IN THE LAST WEEK?"
# # 
# surv_rnd=data.frame(sdi$YEAR_OF_BIRTH,
# 			sdi$ad6,
# 			sdi$ap65,
# 			sdi$ap83_2,
# 			sdi$fp55,
# 			sdi$fp56,
# 			sdi$fp65,
# 			sdi$fp66,
# 			sdi$HP111_1,
# 			sdi$HP131,
# 			sdi$HP133)
# 
# write.csv(surv_rnd, file="surv_rnd.csv", row.names=FALSE)
# 
